==> james-project-3.5.0-source-release.zip: james-project-3.5.0/server/container/guice/mailbox/src/main/java/org/apache/james/modules/EventDeadLettersProbe.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules;

import javax.inject.Inject;

import org.apache.james.mailbox.events.EventDeadLetters;
import org.apache.james.utils.GuiceProbe;

public class EventDeadLettersProbe implements GuiceProbe {

    private final EventDeadLetters eventDeadLetters;

    @Inject
    public EventDeadLettersProbe(EventDeadLetters eventDeadLetters) {
        this.eventDeadLetters = eventDeadLetters;
    }

    public EventDeadLetters getEventDeadLetters() {
        return eventDeadLetters;
    }
}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/server/container/guice/mailbox/src/main/java/org/apache/james/modules/EventDeadLettersProbe.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules;

import javax.inject.Inject;

import org.apache.james.events.EventDeadLetters;
import org.apache.james.utils.GuiceProbe;

public class EventDeadLettersProbe implements GuiceProbe {

    private final EventDeadLetters eventDeadLetters;

    @Inject
    public EventDeadLettersProbe(EventDeadLetters eventDeadLetters) {
        this.eventDeadLetters = eventDeadLetters;
    }

    public EventDeadLetters getEventDeadLetters() {
        return eventDeadLetters;
    }
}
